@@ -1,4 +1,4 @@
 from __future__ import absolute_import
 from .daml_client import *
 
-name = "daml_client"
+name = "lybluely"
